injectmock
=====

Inject mock and restore original for javascript property.  Useful for unit testing.

<!-- Badge start -->

[![Build Status][my_travis_badge_url]][my_travis_url]
[![Code Climate][my_codeclimate_badge_url]][my_codeclimate_url]
[![Code Coverage][my_codeclimate_coverage_badge_url]][my_codeclimate_url]
[![npm version][my_npm_budge_url]][my_npm_url]

Usage
-----

Injecting mock:

```javascript
var injectmock = require('injectmock');
injectmock(myModule, 'myFunction', myMockFunction);
```

Restoring Original:

```javascript
injectmock.restoreAll();
```


Examples
-----

Work with nodeunit setUp/tearDown method:

```javascript
/**
 * This an example inject mock for nodeunit test.
 */

var injectmock = require('injectmock');

// Disable console.log before test started.
exports.setUp = function(done) {
    function mockLog(){
    });
    
    // Inject `mockLog` as `console.log`. 
    injectmock(console, 'log', mockLog);
     
    done();    
}

// Disable console.log before test done.
exports.tearDown = function(done) {
    // Restore all injected.
    injectmock.restoreAll();
    
    console.log('Now I am back!');
            
    done();
};


```


Installation
-----

Install module via [npm][npm_url]

```bash
npm install injectmock --save-dev
```


APIGuide
-----

#### `injectmock(module, key, value)`

Inject a mock to module. 

 
#### `injectmock.restore(module, key)` 

Restore an injected. 


#### `injectmock.restoreAll()` 

Restore all injected. 


#### `injectmock.new()` 

Returns a new `injectmock` context, which has separated mock stacks.
 

#### `injectmock.noop()` 

Do nothing. You can use this method as mock to do nothing. 


License
-------
This software is released under the [MIT License][my_license_url].



<!-- Links start -->

[nodejs_url]: http://nodejs.org/
[npm_url]: https://www.npmjs.com/
[nvm_url]: https://github.com/creationix/nvm
[bitdeli_url]: https://bitdeli.com/free
[my_bitdeli_badge_url]: https://d2weczhvl823v0.cloudfront.net/okunishinishi/node-injectmock/trend.png
[my_repo_url]: https://github.com/okunishinishi/node-injectmock
[my_travis_url]: http://travis-ci.org/okunishinishi/node-injectmock
[my_travis_badge_url]: http://img.shields.io/travis/okunishinishi/node-injectmock.svg?style=flat
[my_license_url]: https://github.com/okunishinishi/node-injectmock/blob/master/LICENSE
[my_codeclimate_url]: http://codeclimate.com/github/okunishinishi/node-injectmock
[my_codeclimate_badge_url]: http://img.shields.io/codeclimate/github/okunishinishi/node-injectmock.svg?style=flat
[my_codeclimate_coverage_badge_url]: http://img.shields.io/codeclimate/coverage/github/okunishinishi/node-injectmock.svg?style=flat
[my_apiguide_url]: http://okunishinishi.github.io/node-injectmock/apiguide
[my_lib_apiguide_url]: http://okunishinishi.github.io/node-injectmock/apiguide/module-injectmock_lib.html
[my_coverage_url]: http://okunishinishi.github.io/node-injectmock/coverage/lcov-report
[my_coverage_report_url]: http://okunishinishi.github.io/node-injectmock/coverage/lcov-report/
[my_gratipay_url]: https://gratipay.com/okunishinishi/
[my_gratipay_budge_url]: http://img.shields.io/gratipay/okunishinishi.svg?style=flat
[my_npm_url]: http://www.npmjs.org/package/injectmock
[my_npm_budge_url]: http://img.shields.io/npm/v/injectmock.svg?style=flat
[my_tag_url]: http://github.com/okunishinishi/node-injectmock/releases/tag/
[my_tag_badge_url]: http://img.shields.io/github/tag/okunishinishi/node-injectmock.svg?style=flat

<!-- Links end -->
